@@ -12,7 +12,11 @@
 
 #undef bool
 #include "qwindow.h"
-#include "virtual.h"
+#include "pwidget.h"
+
+#define QWindow_virtual_functions QWidget_virtual_functions
+
+class PWindow_virtualize : public PWidget_virtualize {};
 
 class PWindow : public QWindow, public PWindow_virtualize {
     QWindow_virtual_functions
